==> nextcloud-29.0.12.tgz: nextcloud/apps/photos/l10n/ug.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "ئاممىۋى ئۇلىنىش",
    "Photos" : "Photos",
    "On This Day" : "بۇ كۈندە",
    "Your memories under your control" : "ئەسلىمىلىرىڭىز سىزنىڭ كونتروللۇقىڭىزدا",
    "All media" : "بارلىق تاراتقۇلار",
    "Videos" : "سىنلار",
    "Albums" : "Album",
    "Collaborative albums" : "ھەمكارلىق پىلاستىنكىسى",
    "People" : "كىشىلەر",
    "Folders" : "ھۆججەت قىسقۇچ",
    "Favorites" : "يىغقۇچ",
    "On this day" : "بۇ كۈنى",
    "Shared with you" : "Shared with you",
    "Tags" : "بەلگەلەر",
    "Places" : "جايلار",
    "Map" : "خەرىتە",
    "Photos settings" : "رەسىم تەڭشىكى",
    "Mark selection as favorite" : "تاللاشقا ئامراق دەپ بەلگە قويۇڭ",
    "Add selection to favorites" : "ياقتۇرىدىغانلارغا تاللاش قوشۇڭ",
    "Remove selection from favorites" : "ياقتۇرىدىغانلاردىن تاللاشنى ئۆچۈرۈڭ",
    "Name of the album" : "پىلاستىنكىنىڭ ئىسمى",
    "Location of the album" : "ئالبۇمنىڭ ئورنى",
    "Back" : "قايتىش",
    "Add collaborators" : "ھەمكارلاشقۇچىلارنى قوشۇڭ",
    "Save" : "ساقلا",
    "Create album" : "پىلاستىنكا قۇرۇش",
    "Add to Album" : "ئالبۇمغا قوشۇڭ",
    "Add selection to album {albumName}" : "پىلاستىنكا تاللاش {albumName}",
    "Shared by" : "ھەمبەھىرلىگۈچى",
    "Create a new album." : "يېڭى پىلاستىنكا قۇر.",
    "Create new album" : "يېڭى پىلاستىنكا قۇر",
    "New album" : "يېڭى پىلاستىنكا",
    "Add people or groups who can edit your album" : "پىلاستىنكىڭىزنى تەھرىرلىيەلەيدىغان كىشىلەر ياكى گۇرۇپپىلارنى قوشۇڭ",
    "Search people or groups" : "كىشىلەرنى ياكى گۇرۇپپىلارنى ئىزدەڭ",
    "No recommendations. Start typing." : "تەۋسىيە يوق. يېزىشنى باشلاڭ.",
    "Group" : "گۇرۇپپا",
    "Remove {collaboratorLabel} from the collaborators list" : "ھەمكارلاشقۇچىلار تىزىملىكىدىن {collaboratorLabel} Label ئۆچۈرۈڭ",
    "Copy the public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Public link copied!" : "ئاممىۋى ئۇلىنىش كۆچۈرۈلدى!",
    "Copy public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Delete the public link" : "ئاممىۋى ئۇلىنىشنى ئۆچۈرۈڭ",
    "Create public link share" : "ئاممىۋى ئۇلىنىش ئورتاقلىشىش",
    "Share via public link" : "ئاممىۋى ئۇلىنىش ئارقىلىق ھەمبەھىرلەڭ",
    "Failed to fetch collaborators list." : "ھەمكارلاشقۇچىلار تىزىملىكىنى ئالالمىدى.",
    "Failed to update album." : "پىلاستىنكىنى يېڭىلاش مەغلۇب بولدى.",
    "This collection does not exist" : "بۇ توپلام مەۋجۇت ئەمەس",
    "An error occurred" : "خاتالىق كۆرۈلدى",
    "No picture for this day" : "بۇ كۈنگە ھېچقانداق رەسىم يوق",
    "Picture taken on this day will show up here." : "بۇ كۈنى تارتىلغان رەسىم بۇ يەردە كۆرسىتىلىدۇ.",
    "More photos from this day" : "بۇ كۈندىن باشلاپ تېخىمۇ كۆپ سۈرەتلەر",
    "Favorite" : "يىغقۇچ",
    "Select image {imageName}" : "رەسىم {imageName} Select نى تاللاڭ",
    "Favorite image, open the full size \"{name}\" image" : "ياقتۇرىدىغان رەسىم ، چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Open the full size \"{name}\" image" : "تولۇق چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Open the \"{name}\" folder" : "\"{name}\" ھۆججەت قىسقۇچىنى ئېچىڭ",
    "Go back" : "قايتىڭ",
    "Back to {folder}" : "{folder} قايتىش",
    "Share this folder" : "بۇ قىسقۇچنى ھەمبەھىرلەڭ",
    "Dates" : "چېسلا",
    "Jump to specific date in list" : "تىزىملىكتىكى كونكرېت چېسلاغا ئاتلاڭ",
    "Jump to {date}" : "{date} ئاتلاڭ",
    "Add to {destination}" : "{destination} قوش",
    "The destination folder is owned by {owner}" : "نىشان ھۆججەت قىسقۇچى {owner} نىڭ ئىگىدارچىلىقىدا",
    "There are no photos or videos yet!" : "ھازىرچە رەسىم ياكى سىن يوق!",
    "Enable squared photos view" : "كۋادرات رەسىم كۆرۈنۈشىنى قوزغىتىڭ",
    "Delete source directory" : "مەنبە مۇندەرىجىسىنى ئۆچۈرۈڭ",
    "All folders" : "بارلىق ھۆججەت قىسقۇچلار",
    "Add a Photos source for the timelines" : "ۋاقىت جەدۋىلىگە رەسىم مەنبەسىنى قوشۇڭ",
    "Add folder" : "قىسقۇچ قوشۇڭ",
    "Select a source folder for your media" : "مېدىياڭىزنىڭ مەنبە قىسقۇچىنى تاللاڭ",
    "Home" : "ئۆي",
    "Choose default Photos upload and Albums location" : "سۈكۈتتىكى رەسىم يوللاش ۋە پىلاستىنكا ئورنىنى تاللاڭ",
    "Choose a different folder" : "باشقا ھۆججەت قىسقۇچنى تاللاڭ",
    "Select the default upload location for your media" : "مېدىياڭىزنىڭ سۈكۈتتىكى يۈكلەش ئورنىنى تاللاڭ",
    "View" : "كۆرۈش",
    "Media folders" : "مېدىيا قىسقۇچلىرى",
    "Choose the folders from where photos and videos are shown." : "رەسىم ۋە سىن كۆرسىتىلگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Upload folder" : "ھۆججەت قىسقۇچنى يۈكلەڭ",
    "Choose the folder where photos and albums are uploaded to." : "رەسىم ۋە پىلاستىنكىلار يۈكلەنگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Unselect all" : "ھەممىنى تاللاڭ",
    "Add photos to this album" : "بۇ پىلاستىنكىغا رەسىم قوشۇڭ",
    "Manage collaborators for this album" : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى باشقۇرۇڭ",
    "Open actions menu" : "ھەرىكەت تىزىملىكى",
    "Edit album details" : "پىلاستىنكا تەپسىلاتلىرىنى تەھرىرلەڭ",
    "Download all files in album" : "ئالبۇمدىكى بارلىق ھۆججەتلەرنى چۈشۈرۈڭ",
    "Delete album" : "ئالبۇمنى ئۆچۈرۈڭ",
    "Download selected files" : "تاللانغان ھۆججەتلەرنى چۈشۈرۈڭ",
    "Remove selection from album" : "ئالبۇمدىن تاللاشنى ئۆچۈرۈڭ",
    "This album does not have any photos or videos yet!" : "بۇ پىلاستىنكىدا ھازىرچە ھېچقانداق رەسىم ياكى سىن يوق!",
    "Add photos to {albumName}" : "{albumName} to غا رەسىم قوشۇڭ",
    "Manage collaborators" : "ھەمكارلاشقۇچىلارنى باشقۇرۇش",
    "Save collaborators for this album." : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى ساقلاڭ.",
    "Cover photo for album {albumName}" : "پىلاستىنكا {albumName} for نىڭ مۇقاۋا سۈرىتى",
    "There is no album yet!" : "ھازىرچە ئالبۇم يوق!",
    "This person could not be found" : "بۇ ئادەمنى تاپالمىدى",
    "Rename person" : "ئادەمنىڭ نامىنى ئۆزگەرتىش",
    "Merge with different person" : "ئوخشىمىغان ئادەم بىلەن بىرلەشتۈرۈڭ",
    "Download selected photos" : "تاللانغان رەسىملەرنى چۈشۈرۈڭ",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "ئادەمنى چىقىرىۋېتىڭ",
    "Name of this person" : "بۇ كىشىنىڭ ئىسمى",
    "Save." : "ساقلاش.",
    "Merge person" : "ئادەمنى بىرلەشتۈرۈش",
    "Move to different person" : "ئوخشىمىغان ئادەمگە يۆتكىڭ",
    "This might take some time depending on the size of your photo library." : "رەسىم ئامبىرىڭىزنىڭ چوڭ-كىچىكلىكىگە ئاساسەن بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
    "Recognized people will show up here" : "تونۇلغان كىشىلەر بۇ يەردە پەيدا بولىدۇ",
    "This folder does not exist" : "بۇ ھۆججەت قىسقۇچ مەۋجۇت ئەمەس",
    "Loading folders …" : "ھۆججەت قىسقۇچلارنى يۈكلەۋاتىدۇ…",
    "No photos in here" : "بۇ يەردە رەسىم يوق",
    "Taken on {date} at {time}" : "{date} دا {time} دىن ئېلىندى",
    "This place does not have any photos or videos yet!" : "بۇ يەرنىڭ تېخى رەسىم ياكى سىن يوق!",
    "Add photos to this place" : "بۇ يەرگە رەسىم قوشۇڭ",
    "Cover photo for place {placeName}" : "ئورۇننىڭ يېپىلىش سۈرىتى {placeName}",
    "There is no place yet!" : "ھازىرچە يەر يوق!",
    "Cover photo for shared album {albumName}." : "ھەمبەھىرلەنگەن پىلاستىنكا {albumName} for نىڭ مۇقاۋا سۈرىتى.",
    "Back to tags overview" : "خەتكۈچ ئومۇمىي كۆرۈنۈشىگە قايتىڭ",
    "No photos with this tag yet" : "بۇ خەتكۈچ بىلەن رەسىم يوق",
    "No tags yet" : "خەتكۈچ يوق",
    "Photos with tags will show up here" : "بەلگە قويۇلغان رەسىملەر بۇ يەردە كۆرۈنىدۇ",
    "Popular tags" : "داڭلىق خەتكۈچلەر",
    "All tags" : "بارلىق خەتكۈچلەر",
    "Add to album" : "ئالبۇمغا قوشۇڭ",
    "Delete selection" : "تاللاشنى ئۆچۈرۈڭ",
    "No photos or videos in here" : "بۇ يەردە رەسىم ياكى سىن يوق",
    "Unassigned faces" : "ئىمزاسىز چىراي",
    "Failed to fetch collection." : "يىغىش مەغلۇب بولدى.",
    "Failed to fetch collections list." : "يىغىپ ساقلاش تىزىملىكىنى ئالالمىدى.",
    "Failed to fetch faces list." : "چىراي تىزىملىكىنى ئالالمىدى.",
    "All your media" : "بارلىق مېدىيالىرىڭىز",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "ھەمبەھىرلەنگەن ئالبۇم",
    "Shared album {title}" : "ھەمبەھىرلەنگەن پىلاستىنكا {title}",
    "Public album {title}" : "ئاممىۋى پىلاستىنكا {title}",
    "Tagged photos" : "خەتكۈچلەنگەن رەسىملەر",
    "Tagged photo {title}" : "خەتكۈچلەنگەن رەسىم {title}",
    "{title}'s face" : "{title} 'face",
    "{startDate} to {endDate}" : "{startDate} دىن {endDate}",
    "Details" : "تەپسىلاتى",
    "Failed to rename {oldName} to {faceName}." : "{oldName} نىڭ نامىنى {faceName} غا ئۆزگەرتەلمىدى.",
    "Failed to delete {faceName}." : "{faceName} نى ئۆچۈرەلمىدى.",
    "Failed to delete {fileId}." : "{fileId} نى ئۆچۈرەلمىدى.",
    "Failed to delete {fileName}." : "{fileName} نى ئۆچۈرەلمىدى.",
    "Failed to set favorite state for {fileId}." : "{fileId} for ئۈچۈن ياخشى كۆرىدىغان ھالەتنى بەلگىلىيەلمىدى.",
    "Failed to set favorite state for {fileName}." : "{fileName} for ئۈچۈن ياقتۇرىدىغان ھالەتنى بەلگىلىيەلمىدى.",
    "Could not load photos folder" : "رەسىم قىسقۇچنى يۈكلىيەلمىدى",
    "One of the source folders does not exists" : "مەنبە قىسقۇچلارنىڭ بىرى مەۋجۇت ئەمەس",
    "Add" : "قوش"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/photos/l10n/ug.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "ئاممىۋى ئۇلىنىش",
    "Photos" : "Photos",
    "On This Day" : "بۇ كۈندە",
    "Your memories under your control" : "ئەسلىمىلىرىڭىز سىزنىڭ كونتروللۇقىڭىزدا",
    "All media" : "بارلىق تاراتقۇلار",
    "Videos" : "سىنلار",
    "Albums" : "Album",
    "Collaborative albums" : "ھەمكارلىق پىلاستىنكىسى",
    "People" : "كىشىلەر",
    "Folders" : "ھۆججەت قىسقۇچ",
    "Favorites" : "يىغقۇچ",
    "On this day" : "بۇ كۈنى",
    "Shared with you" : "Shared with you",
    "Tags" : "بەلگەلەر",
    "Places" : "جايلار",
    "Map" : "خەرىتە",
    "Photos settings" : "رەسىم تەڭشىكى",
    "Mark selection as favorite" : "تاللاشقا ئامراق دەپ بەلگە قويۇڭ",
    "Add selection to favorites" : "ياقتۇرىدىغانلارغا تاللاش قوشۇڭ",
    "Remove selection from favorites" : "ياقتۇرىدىغانلاردىن تاللاشنى ئۆچۈرۈڭ",
    "Name of the album" : "پىلاستىنكىنىڭ ئىسمى",
    "Location of the album" : "ئالبۇمنىڭ ئورنى",
    "Back" : "قايتىش",
    "Add collaborators" : "ھەمكارلاشقۇچىلارنى قوشۇڭ",
    "Save" : "ساقلا",
    "Create album" : "پىلاستىنكا قۇرۇش",
    "Add to Album" : "ئالبۇمغا قوشۇڭ",
    "Add selection to album {albumName}" : "پىلاستىنكا تاللاش {albumName}",
    "Shared by" : "ھەمبەھىرلىگۈچى",
    "Create a new album." : "يېڭى پىلاستىنكا قۇر.",
    "Create new album" : "يېڭى پىلاستىنكا قۇر",
    "New album" : "يېڭى پىلاستىنكا",
    "Add people or groups who can edit your album" : "پىلاستىنكىڭىزنى تەھرىرلىيەلەيدىغان كىشىلەر ياكى گۇرۇپپىلارنى قوشۇڭ",
    "Search people or groups" : "كىشىلەرنى ياكى گۇرۇپپىلارنى ئىزدەڭ",
    "No recommendations. Start typing." : "تەۋسىيە يوق. يېزىشنى باشلاڭ.",
    "Group" : "گۇرۇپپا",
    "Remove {collaboratorLabel} from the collaborators list" : "ھەمكارلاشقۇچىلار تىزىملىكىدىن {collaboratorLabel} Label ئۆچۈرۈڭ",
    "Copy the public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Public link copied!" : "ئاممىۋى ئۇلىنىش كۆچۈرۈلدى!",
    "Copy public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Delete the public link" : "ئاممىۋى ئۇلىنىشنى ئۆچۈرۈڭ",
    "Create public link share" : "ئاممىۋى ئۇلىنىش ئورتاقلىشىش",
    "Share via public link" : "ئاممىۋى ئۇلىنىش ئارقىلىق ھەمبەھىرلەڭ",
    "Failed to fetch collaborators list." : "ھەمكارلاشقۇچىلار تىزىملىكىنى ئالالمىدى.",
    "Failed to update album." : "پىلاستىنكىنى يېڭىلاش مەغلۇب بولدى.",
    "This collection does not exist" : "بۇ توپلام مەۋجۇت ئەمەس",
    "An error occurred" : "خاتالىق كۆرۈلدى",
    "No picture for this day" : "بۇ كۈنگە ھېچقانداق رەسىم يوق",
    "Picture taken on this day will show up here." : "بۇ كۈنى تارتىلغان رەسىم بۇ يەردە كۆرسىتىلىدۇ.",
    "More photos from this day" : "بۇ كۈندىن باشلاپ تېخىمۇ كۆپ سۈرەتلەر",
    "Favorite" : "يىغقۇچ",
    "Select image {imageName}" : "رەسىم {imageName} Select نى تاللاڭ",
    "Favorite image, open the full size \"{name}\" image" : "ياقتۇرىدىغان رەسىم ، چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Open the full size \"{name}\" image" : "تولۇق چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Open the \"{name}\" folder" : "\"{name}\" ھۆججەت قىسقۇچىنى ئېچىڭ",
    "Go back" : "قايتىڭ",
    "Back to {folder}" : "{folder} قايتىش",
    "Share this folder" : "بۇ قىسقۇچنى ھەمبەھىرلەڭ",
    "Dates" : "چېسلا",
    "Jump to specific date in list" : "تىزىملىكتىكى كونكرېت چېسلاغا ئاتلاڭ",
    "Jump to {date}" : "{date} ئاتلاڭ",
    "Add to {destination}" : "{destination} قوش",
    "The destination folder is owned by {owner}" : "نىشان ھۆججەت قىسقۇچى {owner} نىڭ ئىگىدارچىلىقىدا",
    "There are no photos or videos yet!" : "ھازىرچە رەسىم ياكى سىن يوق!",
    "Enable squared photos view" : "كۋادرات رەسىم كۆرۈنۈشىنى قوزغىتىڭ",
    "Delete source directory" : "مەنبە مۇندەرىجىسىنى ئۆچۈرۈڭ",
    "All folders" : "بارلىق ھۆججەت قىسقۇچلار",
    "Add a Photos source for the timelines" : "ۋاقىت جەدۋىلىگە رەسىم مەنبەسىنى قوشۇڭ",
    "Add folder" : "قىسقۇچ قوشۇڭ",
    "Select a source folder for your media" : "مېدىياڭىزنىڭ مەنبە قىسقۇچىنى تاللاڭ",
    "Home" : "ئۆي",
    "Choose default Photos upload and Albums location" : "سۈكۈتتىكى رەسىم يوللاش ۋە پىلاستىنكا ئورنىنى تاللاڭ",
    "Choose a different folder" : "باشقا ھۆججەت قىسقۇچنى تاللاڭ",
    "Select the default upload location for your media" : "مېدىياڭىزنىڭ سۈكۈتتىكى يۈكلەش ئورنىنى تاللاڭ",
    "View" : "كۆرۈش",
    "Media folders" : "مېدىيا قىسقۇچلىرى",
    "Choose the folders from where photos and videos are shown." : "رەسىم ۋە سىن كۆرسىتىلگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Upload folder" : "ھۆججەت قىسقۇچنى يۈكلەڭ",
    "Choose the folder where photos and albums are uploaded to." : "رەسىم ۋە پىلاستىنكىلار يۈكلەنگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Unselect all" : "ھەممىنى تاللاڭ",
    "Manage collaborators for this album" : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى باشقۇرۇڭ",
    "Open actions menu" : "ھەرىكەت تىزىملىكى",
    "Edit album details" : "پىلاستىنكا تەپسىلاتلىرىنى تەھرىرلەڭ",
    "Download all files in album" : "ئالبۇمدىكى بارلىق ھۆججەتلەرنى چۈشۈرۈڭ",
    "Delete album" : "ئالبۇمنى ئۆچۈرۈڭ",
    "Download selected files" : "تاللانغان ھۆججەتلەرنى چۈشۈرۈڭ",
    "Remove selection from album" : "ئالبۇمدىن تاللاشنى ئۆچۈرۈڭ",
    "This album does not have any photos or videos yet!" : "بۇ پىلاستىنكىدا ھازىرچە ھېچقانداق رەسىم ياكى سىن يوق!",
    "Add photos to this album" : "بۇ پىلاستىنكىغا رەسىم قوشۇڭ",
    "Add photos to {albumName}" : "{albumName} to غا رەسىم قوشۇڭ",
    "Manage collaborators" : "ھەمكارلاشقۇچىلارنى باشقۇرۇش",
    "Save collaborators for this album." : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى ساقلاڭ.",
    "Cover photo for album {albumName}" : "پىلاستىنكا {albumName} for نىڭ مۇقاۋا سۈرىتى",
    "There is no album yet!" : "ھازىرچە ئالبۇم يوق!",
    "This person could not be found" : "بۇ ئادەمنى تاپالمىدى",
    "Rename person" : "ئادەمنىڭ نامىنى ئۆزگەرتىش",
    "Merge with different person" : "ئوخشىمىغان ئادەم بىلەن بىرلەشتۈرۈڭ",
    "Download selected photos" : "تاللانغان رەسىملەرنى چۈشۈرۈڭ",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "ئادەمنى چىقىرىۋېتىڭ",
    "Name of this person" : "بۇ كىشىنىڭ ئىسمى",
    "Save." : "ساقلاش.",
    "Merge person" : "ئادەمنى بىرلەشتۈرۈش",
    "Move to different person" : "ئوخشىمىغان ئادەمگە يۆتكىڭ",
    "This might take some time depending on the size of your photo library." : "رەسىم ئامبىرىڭىزنىڭ چوڭ-كىچىكلىكىگە ئاساسەن بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
    "Recognized people will show up here" : "تونۇلغان كىشىلەر بۇ يەردە پەيدا بولىدۇ",
    "This folder does not exist" : "بۇ ھۆججەت قىسقۇچ مەۋجۇت ئەمەس",
    "Loading folders …" : "ھۆججەت قىسقۇچلارنى يۈكلەۋاتىدۇ…",
    "No photos in here" : "بۇ يەردە رەسىم يوق",
    "Taken on {date} at {time}" : "{date} دا {time} دىن ئېلىندى",
    "This place does not have any photos or videos yet!" : "بۇ يەرنىڭ تېخى رەسىم ياكى سىن يوق!",
    "Add photos to this place" : "بۇ يەرگە رەسىم قوشۇڭ",
    "Cover photo for place {placeName}" : "ئورۇننىڭ يېپىلىش سۈرىتى {placeName}",
    "There is no place yet!" : "ھازىرچە يەر يوق!",
    "Cover photo for shared album {albumName}." : "ھەمبەھىرلەنگەن پىلاستىنكا {albumName} for نىڭ مۇقاۋا سۈرىتى.",
    "Back to tags overview" : "خەتكۈچ ئومۇمىي كۆرۈنۈشىگە قايتىڭ",
    "No photos with this tag yet" : "بۇ خەتكۈچ بىلەن رەسىم يوق",
    "No tags yet" : "خەتكۈچ يوق",
    "Photos with tags will show up here" : "بەلگە قويۇلغان رەسىملەر بۇ يەردە كۆرۈنىدۇ",
    "Popular tags" : "داڭلىق خەتكۈچلەر",
    "All tags" : "بارلىق خەتكۈچلەر",
    "Add" : "قوش",
    "Add to album" : "ئالبۇمغا قوشۇڭ",
    "Delete selection" : "تاللاشنى ئۆچۈرۈڭ",
    "No photos or videos in here" : "بۇ يەردە رەسىم ياكى سىن يوق",
    "Unassigned faces" : "ئىمزاسىز چىراي",
    "Failed to fetch collection." : "يىغىش مەغلۇب بولدى.",
    "Failed to fetch collections list." : "يىغىپ ساقلاش تىزىملىكىنى ئالالمىدى.",
    "Failed to fetch faces list." : "چىراي تىزىملىكىنى ئالالمىدى.",
    "All your media" : "بارلىق مېدىيالىرىڭىز",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "ھەمبەھىرلەنگەن ئالبۇم",
    "Shared album {title}" : "ھەمبەھىرلەنگەن پىلاستىنكا {title}",
    "Public album {title}" : "ئاممىۋى پىلاستىنكا {title}",
    "Tagged photos" : "خەتكۈچلەنگەن رەسىملەر",
    "Tagged photo {title}" : "خەتكۈچلەنگەن رەسىم {title}",
    "{title}'s face" : "{title} 'face",
    "{startDate} to {endDate}" : "{startDate} دىن {endDate}",
    "Details" : "تەپسىلاتى",
    "Failed to rename {oldName} to {faceName}." : "{oldName} نىڭ نامىنى {faceName} غا ئۆزگەرتەلمىدى.",
    "Failed to delete {faceName}." : "{faceName} نى ئۆچۈرەلمىدى.",
    "Failed to delete {fileId}." : "{fileId} نى ئۆچۈرەلمىدى.",
    "Failed to delete {fileName}." : "{fileName} نى ئۆچۈرەلمىدى.",
    "Failed to set favorite state for {fileId}." : "{fileId} for ئۈچۈن ياخشى كۆرىدىغان ھالەتنى بەلگىلىيەلمىدى.",
    "Failed to set favorite state for {fileName}." : "{fileName} for ئۈچۈن ياقتۇرىدىغان ھالەتنى بەلگىلىيەلمىدى.",
    "Could not load photos folder" : "رەسىم قىسقۇچنى يۈكلىيەلمىدى",
    "Default Photos upload and Albums location" : "سۈكۈتتىكى رەسىملەرنى يوللاش ۋە پىلاستىنكا ئورنى",
    "Select the default location for your media" : "مېدىياڭىزنىڭ سۈكۈتتىكى ئورنىنى تاللاڭ",
    "Invalid location selected" : "ئىناۋەتسىز ئورۇن تاللانغان",
    "Photos directory" : "رەسىم مۇندەرىجىسى",
    "One of the source folders does not exists" : "مەنبە قىسقۇچلارنىڭ بىرى مەۋجۇت ئەمەس"
},
"nplurals=2; plural=(n != 1);");
